==> arknights_mower-2.0.0a6-py3-none-any.whl: arknights_mower/data/recruit.py <==
# recruit database

recruit_database = [
    ('Lancet-2', 1, ['医疗干员', '远程位', '治疗', '支援机械']),
    ('Castle-3', 1, ['近卫干员', '近战位', '支援', '支援机械']),
    ('夜刀', 2, ['先锋干员', '近战位', '新手']),
    ('黑角', 2, ['重装干员', '近战位', '新手']),
    ('巡林者', 2, ['狙击干员', '远程位', '新手']),
    ('杜林', 2, ['术师干员', '远程位', '新手']),
    ('12F', 2, ['术师干员', '远程位', '新手']),
    ('芬', 3, ['先锋干员', '近战位', '费用回复']),
    ('香草', 3, ['先锋干员', '近战位', '费用回复']),
    ('翎羽', 3, ['先锋干员', '近战位', '输出', '费用回复']),
    ('玫兰莎', 3, ['近卫干员', '近战位', '输出', '生存']),
    ('米格鲁', 3, ['重装干员', '近战位', '防护']),
    ('克洛丝', 3, ['狙击干员', '远程位', '输出']),
    ('安德切尔', 3, ['狙击干员', '远程位', '输出']),
    ('炎熔', 3, ['术师干员', '远程位', '群攻']),
    ('芙蓉', 3, ['医疗干员', '远程位', '治疗']),
    ('安赛尔', 3, ['医疗干员', '远程位', '治疗']),
    ('史都华德', 3, ['术师干员', '远程位', '输出']),
    ('梓兰', 3, ['辅助干员', '远程位', '减速']),
    ('夜烟', 4, ['术师干员', '远程位', '输出', '削弱']),
    ('远山', 4, ['术师干员', '远程位', '群攻']),
    ('杰西卡', 4, ['狙击干员', '远程位', '输出', '生存']),
    ('流星', 4, ['狙击干员', '远程位', '输出', '削弱']),
    ('白雪', 4, ['狙击干员', '远程位', '群攻', '减速']),
    ('清道夫', 4, ['先锋干员', '近战位', '费用回复', '输出']),
    ('红豆', 4, ['先锋干员', '近战位', '输出', '费用回复']),
    ('杜宾', 4, ['近卫干员', '近战位', '输出', '支援']),
    ('缠丸', 4, ['近卫干员', '近战位', '生存', '输出']),
    ('霜叶', 4, ['近卫干员', '近战位', '减速', '输出']),
    ('艾丝黛尔', 4, ['近卫干员', '近战位', '群攻', '生存']),
    ('慕斯', 4, ['近卫干员', '近战位', '输出']),
    ('砾', 4, ['特种干员', '近战位', '快速复活', '防护']),
    ('暗索', 4, ['特种干员', '近战位', '位移']),
    ('末药', 4, ['医疗干员', '远程位', '治疗']),
    ('嘉维尔', 4, ['医疗干员', '远程位', '治疗']),
    ('调香师', 4, ['医疗干员', '远程位', '治疗']),
    ('角峰', 4, ['重装干员', '近战位', '防护']),
    ('蛇屠箱', 4, ['重装干员', '近战位', '防护']),
    ('古米', 4, ['重装干员', '近战位', '防护', '治疗']),
    ('地灵', 4, ['辅助干员', '远程位', '减速']),
    ('阿消', 4, ['特种干员', '近战位', '位移']),
    ('白面鸮', 5, ['医疗干员', '远程位', '治疗', '支援']),
    ('凛冬', 5, ['先锋干员', '近战位', '费用回复', '支援']),
    ('德克萨斯', 5, ['先锋干员', '近战位', '费用回复', '控场']),
    ('因陀罗', 5, ['近卫干员', '近战位', '输出', '生存']),
    ('幽灵鲨', 5, ['近卫干员', '近战位', '群攻', '生存']),
    ('蓝毒', 5, ['狙击干员', '远程位', '输出']),
    ('白金', 5, ['狙击干员', '远程位', '输出']),
    ('陨星', 5, ['狙击干员', '远程位', '群攻', '削弱']),
    ('梅尔', 5, ['辅助干员', '远程位', '召唤', '控场']),
    ('赫默', 5, ['医疗干员', '远程位', '治疗']),
    ('华法琳', 5, ['医疗干员', '远程位', '治疗', '支援']),
    ('临光', 5, ['重装干员', '近战位', '防护', '治疗']),
    ('红', 5, ['特种干员', '近战位', '快速复活', '控场']),
    ('雷蛇', 5, ['重装干员', '近战位', '防护', '输出']),
    ('可颂', 5, ['重装干员', '近战位', '防护', '位移']),
    ('火神', 5, ['重装干员', '近战位', '生存', '防护', '输出']),
    ('普罗旺斯', 5, ['狙击干员', '远程位', '输出']),
    ('守林人', 5, ['狙击干员', '远程位', '输出', '爆发']),
    ('崖心', 5, ['特种干员', '近战位', '位移', '输出']),
    ('初雪', 5, ['辅助干员', '远程位', '削弱']),
    ('真理', 5, ['辅助干员', '远程位', '减速', '输出']),
    ('狮蝎', 5, ['特种干员', '近战位', '输出', '生存']),
    ('食铁兽', 5, ['特种干员', '近战位', '位移', '减速']),
    ('能天使', 6, ['狙击干员', '远程位', '输出']),
    ('推进之王', 6, ['先锋干员', '近战位', '费用回复', '输出']),
    ('伊芙利特', 6, ['术师干员', '远程位', '群攻', '削弱']),
    ('闪灵', 6, ['医疗干员', '远程位', '治疗', '支援']),
    ('夜莺', 6, ['医疗干员', '远程位', '治疗', '支援']),
    ('星熊', 6, ['重装干员', '近战位', '防护', '输出']),
    ('塞雷娅', 6, ['重装干员', '近战位', '防护', '治疗', '支援']),
    ('银灰', 6, ['近卫干员', '近战位', '输出', '支援']),
    ('空爆', 3, ['狙击干员', '远程位', '群攻']),
    ('月见夜', 3, ['近卫干员', '近战位', '输出']),
    ('猎蜂', 4, ['近卫干员', '近战位', '输出']),
    ('夜魔', 5, ['术师干员', '远程位', '输出', '治疗', '减速']),
    ('斯卡蒂', 6, ['近卫干员', '近战位', '输出', '生存']),
    ('陈', 6, ['近卫干员', '近战位', '输出', '爆发']),
    ('诗怀雅', 5, ['近卫干员', '近战位', '输出', '支援']),
    ('格雷伊', 4, ['术师干员', '远程位', '群攻', '减速']),
    ('泡普卡', 3, ['近卫干员', '近战位', '群攻', '生存']),
    ('斑点', 3, ['重装干员', '近战位', '防护', '治疗']),
    ('THRM-EX', 1, ['特种干员', '近战位', '爆发', '支援机械']),
    ('黑', 6, ['狙击干员', '远程位', '输出']),
    ('赫拉格', 6, ['近卫干员', '近战位', '输出', '生存']),
    ('格劳克斯', 5, ['辅助干员', '远程位', '减速', '控场']),
    ('星极', 5, ['近卫干员', '近战位', '输出', '防护']),
    ('苏苏洛', 4, ['医疗干员', '远程位', '治疗']),
    ('桃金娘', 4, ['先锋干员', '近战位', '费用回复', '治疗']),
    ('麦哲伦', 6, ['辅助干员', '远程位', '支援', '减速', '输出']),
    ('送葬人', 5, ['狙击干员', '远程位', '群攻']),
    ('红云', 4, ['狙击干员', '远程位', '输出']),
    ('莫斯提马', 6, ['术师干员', '远程位', '群攻', '支援', '控场']),
    ('槐琥', 5, ['特种干员', '近战位', '快速复活', '削弱']),
    ('清流', 4, ['医疗干员', '远程位', '治疗', '支援']),
    ('梅', 4, ['狙击干员', '远程位', '输出', '减速']),
    ('煌', 6, ['近卫干员', '近战位', '输出', '生存']),
    ('灰喉', 5, ['狙击干员', '远程位', '输出']),
    ('苇草', 5, ['先锋干员', '近战位', '费用回复', '输出']),
    ('布洛卡', 5, ['近卫干员', '近战位', '群攻', '生存']),
    ('安比尔', 4, ['狙击干员', '远程位', '输出', '减速']),
    ('阿', 6, ['特种干员', '远程位', '输出', '支援']),
    ('吽', 5, ['重装干员', '近战位', '防护', '治疗']),
    ('正义骑士号', 1, ['狙击干员', '远程位', '支援']),
]

recruit_tag = ['资深干员', '高级资深干员']
for x in recruit_database:
    recruit_tag += x[2]
recruit_tag = list(set(recruit_tag))

recruit_agent = {}
for x in recruit_database:
    recruit_agent[x[0]] = x

==> arknights_mower-2.0.1-py3-none-any.whl: arknights_mower/data/recruit.py <==
# recruit database

# TODO: check/update from gamedata

recruit_database = [
    ('Lancet-2', 1, ['医疗干员', '远程位', '治疗', '支援机械']),
    ('Castle-3', 1, ['近卫干员', '近战位', '支援', '支援机械']),
    ('夜刀', 2, ['先锋干员', '近战位', '新手']),
    ('黑角', 2, ['重装干员', '近战位', '新手']),
    ('巡林者', 2, ['狙击干员', '远程位', '新手']),
    ('杜林', 2, ['术师干员', '远程位', '新手']),
    ('12F', 2, ['术师干员', '远程位', '新手']),
    ('芬', 3, ['先锋干员', '近战位', '费用回复']),
    ('香草', 3, ['先锋干员', '近战位', '费用回复']),
    ('翎羽', 3, ['先锋干员', '近战位', '输出', '费用回复']),
    ('玫兰莎', 3, ['近卫干员', '近战位', '输出', '生存']),
    ('米格鲁', 3, ['重装干员', '近战位', '防护']),
    ('克洛丝', 3, ['狙击干员', '远程位', '输出']),
    ('安德切尔', 3, ['狙击干员', '远程位', '输出']),
    ('炎熔', 3, ['术师干员', '远程位', '群攻']),
    ('芙蓉', 3, ['医疗干员', '远程位', '治疗']),
    ('安赛尔', 3, ['医疗干员', '远程位', '治疗']),
    ('史都华德', 3, ['术师干员', '远程位', '输出']),
    ('梓兰', 3, ['辅助干员', '远程位', '减速']),
    ('夜烟', 4, ['术师干员', '远程位', '输出', '削弱']),
    ('远山', 4, ['术师干员', '远程位', '群攻']),
    ('杰西卡', 4, ['狙击干员', '远程位', '输出', '生存']),
    ('流星', 4, ['狙击干员', '远程位', '输出', '削弱']),
    ('白雪', 4, ['狙击干员', '远程位', '群攻', '减速']),
    ('清道夫', 4, ['先锋干员', '近战位', '费用回复', '输出']),
    ('红豆', 4, ['先锋干员', '近战位', '输出', '费用回复']),
    ('杜宾', 4, ['近卫干员', '近战位', '输出', '支援']),
    ('缠丸', 4, ['近卫干员', '近战位', '生存', '输出']),
    ('霜叶', 4, ['近卫干员', '近战位', '减速', '输出']),
    ('艾丝黛尔', 4, ['近卫干员', '近战位', '群攻', '生存']),
    ('慕斯', 4, ['近卫干员', '近战位', '输出']),
    ('砾', 4, ['特种干员', '近战位', '快速复活', '防护']),
    ('暗索', 4, ['特种干员', '近战位', '位移']),
    ('末药', 4, ['医疗干员', '远程位', '治疗']),
    ('调香师', 4, ['医疗干员', '远程位', '治疗']),
    ('角峰', 4, ['重装干员', '近战位', '防护']),
    ('蛇屠箱', 4, ['重装干员', '近战位', '防护']),
    ('古米', 4, ['重装干员', '近战位', '防护', '治疗']),
    ('地灵', 4, ['辅助干员', '远程位', '减速']),
    ('阿消', 4, ['特种干员', '近战位', '位移']),
    ('白面鸮', 5, ['医疗干员', '远程位', '治疗', '支援']),
    ('凛冬', 5, ['先锋干员', '近战位', '费用回复', '支援']),
    ('德克萨斯', 5, ['先锋干员', '近战位', '费用回复', '控场']),
    ('因陀罗', 5, ['近卫干员', '近战位', '输出', '生存']),
    ('幽灵鲨', 5, ['近卫干员', '近战位', '群攻', '生存']),
    ('蓝毒', 5, ['狙击干员', '远程位', '输出']),
    ('白金', 5, ['狙击干员', '远程位', '输出']),
    ('陨星', 5, ['狙击干员', '远程位', '群攻', '削弱']),
    ('梅尔', 5, ['辅助干员', '远程位', '召唤', '控场']),
    ('赫默', 5, ['医疗干员', '远程位', '治疗']),
    ('华法琳', 5, ['医疗干员', '远程位', '治疗', '支援']),
    ('临光', 5, ['重装干员', '近战位', '防护', '治疗']),
    ('红', 5, ['特种干员', '近战位', '快速复活', '控场']),
    ('雷蛇', 5, ['重装干员', '近战位', '防护', '输出']),
    ('可颂', 5, ['重装干员', '近战位', '防护', '位移']),
    ('火神', 5, ['重装干员', '近战位', '生存', '防护', '输出']),
    ('普罗旺斯', 5, ['狙击干员', '远程位', '输出']),
    ('守林人', 5, ['狙击干员', '远程位', '输出', '爆发']),
    ('崖心', 5, ['特种干员', '近战位', '位移', '输出']),
    ('初雪', 5, ['辅助干员', '远程位', '削弱']),
    ('真理', 5, ['辅助干员', '远程位', '减速', '输出']),
    ('狮蝎', 5, ['特种干员', '近战位', '输出', '生存']),
    ('食铁兽', 5, ['特种干员', '近战位', '位移', '减速']),
    ('能天使', 6, ['狙击干员', '远程位', '输出']),
    ('推进之王', 6, ['先锋干员', '近战位', '费用回复', '输出']),
    ('伊芙利特', 6, ['术师干员', '远程位', '群攻', '削弱']),
    ('闪灵', 6, ['医疗干员', '远程位', '治疗', '支援']),
    ('夜莺', 6, ['医疗干员', '远程位', '治疗', '支援']),
    ('星熊', 6, ['重装干员', '近战位', '防护', '输出']),
    ('塞雷娅', 6, ['重装干员', '近战位', '防护', '治疗', '支援']),
    ('银灰', 6, ['近卫干员', '近战位', '输出', '支援']),
    ('空爆', 3, ['狙击干员', '远程位', '群攻']),
    ('月见夜', 3, ['近卫干员', '近战位', '输出']),
    ('猎蜂', 4, ['近卫干员', '近战位', '输出']),
    ('夜魔', 5, ['术师干员', '远程位', '输出', '治疗', '减速']),
    ('斯卡蒂', 6, ['近卫干员', '近战位', '输出', '生存']),
    ('陈', 6, ['近卫干员', '近战位', '输出', '爆发']),
    ('诗怀雅', 5, ['近卫干员', '近战位', '输出', '支援']),
    ('格雷伊', 4, ['术师干员', '远程位', '群攻', '减速']),
    ('泡普卡', 3, ['近卫干员', '近战位', '群攻', '生存']),
    ('斑点', 3, ['重装干员', '近战位', '防护', '治疗']),
    ('THRM-EX', 1, ['特种干员', '近战位', '爆发', '支援机械']),
    ('黑', 6, ['狙击干员', '远程位', '输出']),
    ('赫拉格', 6, ['近卫干员', '近战位', '输出', '生存']),
    ('格劳克斯', 5, ['辅助干员', '远程位', '减速', '控场']),
    ('星极', 5, ['近卫干员', '近战位', '输出', '防护']),
    ('苏苏洛', 4, ['医疗干员', '远程位', '治疗']),
    ('桃金娘', 4, ['先锋干员', '近战位', '费用回复', '治疗']),
    ('麦哲伦', 6, ['辅助干员', '远程位', '支援', '减速', '输出']),
    ('送葬人', 5, ['狙击干员', '远程位', '群攻']),
    ('红云', 4, ['狙击干员', '远程位', '输出']),
    ('莫斯提马', 6, ['术师干员', '远程位', '群攻', '支援', '控场']),
    ('槐琥', 5, ['特种干员', '近战位', '快速复活', '削弱']),
    ('清流', 4, ['医疗干员', '远程位', '治疗', '支援']),
    ('梅', 4, ['狙击干员', '远程位', '输出', '减速']),
    ('煌', 6, ['近卫干员', '近战位', '输出', '生存']),
    ('灰喉', 5, ['狙击干员', '远程位', '输出']),
    ('苇草', 5, ['先锋干员', '近战位', '费用回复', '输出']),
    ('布洛卡', 5, ['近卫干员', '近战位', '群攻', '生存']),
    ('安比尔', 4, ['狙击干员', '远程位', '输出', '减速']),
    ('阿', 6, ['特种干员', '远程位', '输出', '支援']),
    ('吽', 5, ['重装干员', '近战位', '防护', '治疗']),
    ('正义骑士号', 1, ['狙击干员', '远程位', '支援', '支援机械']),
    ('刻俄柏', 6, ['术师干员', '远程位', '输出', '控场']),
    ('惊蛰', 5, ['术师干员', '远程位', '输出']),
]

recruit_tag = ['资深干员', '高级资深干员']
for x in recruit_database:
    recruit_tag += x[2]
recruit_tag = list(set(recruit_tag))

recruit_agent = {}
for x in recruit_database:
    recruit_agent[x[0]] = x
